@@ -10,13 +10,11 @@ print(f"Importing {os.path.basename(__file__)}...")
 class HomeAssistant:
     """Base Class for HomeAsssitant module"""
 
-    default_api_url = "http://ha.store1.logi.wiki/api"
-
-    def __init__(self, api_url: str = default_api_url):
+    def __init__(self, location: str = "store1"):
         """Get Home Assistant client"""
         self.client = Client(
-            api_url,
-            config.HOMEASSISTANT_API_KEY,
+            config.HOMEASSISTANT_API[location]["url"],
+            config.HOMEASSISTANT_API[location]["key"],
         )
 
     @classmethod
@@ -65,6 +63,23 @@ class Alarm(HomeAssistant):
         self.client.get_domain(self.domain).alarm_disarm(entity_id=self.entity_id)
 
 
+class Lock(HomeAssistant):
+    """Class for Locks"""
+
+    def __init__(self, entity_id: str, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.domain = "lock"
+        self.entity_id = f"{self.domain}.{entity_id}"
+
+    def lock(self):
+        """Lock door"""
+        self.client.get_domain(self.domain).lock(entity_id=self.entity_id)
+
+    def unlock(self):
+        """Unlock door"""
+        self.client.get_domain(self.domain).unlock(entity_id=self.entity_id)
+
+
 if __name__ == "__main__":
-    alarm = Alarm("system")
-    alarm.disarm()
+    car = Lock(entity_id="taylor_swiftly_doors", location="home")
+    car.lock()
